# magician_package
Packaging for magician

This the the packaging for python manager for LDA-FFT code. 

For better understanding of the working please refer - [LDA-FFT](https://github.com/ai-se/LDA_FFT)
